==> aroundme_0_6_6.tar.tgz: aroundme_0_6_6/aroundme/language/1/barnraiser_01/sch_view.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------


//SECTION
$lang['hdr_schedule'] = 						"my schedule";
$lang['hdr_group_schedule'] = 					"group schedule";
$lang['hdr_my_group_schedule_items'] = 			"latest schedule items from my groups";
$lang['hdr_my_network_schedule_items'] = 		"latest schedule items from my network";
$lang['hdr_options'] =							"schedule options";
$lang['hdr_schedule_item_author'] = 			"author";
$lang['hdr_schedule_item_group_author'] = 		"authoring group";
$lang['hdr_task_allocated'] = 					"allocated tasks";
$lang['hdr_task_initiated'] = 					"initiated tasks";
$lang['hdr_event_attendance'] = 				"event attendance";
$lang['hdr_event_initiated'] = 					"initiated events";
$lang['hdr_events'] = 							"events";
$lang['hdr_tasks'] = 							"tasks";
$lang['hdr_schedule_items'] = 					"schedule items";
$lang['hdr_schedule_item'] = 					"schedule item";
$lang['hdr_allocation'] = 						"allocation";
$lang['hdr_detail'] = 							"details";
$lang['hdr_attendance'] = 						"attendance";


// HREF
$lang['href_event_withdraw_confirmation'] = 	"withdraw from this event";
$lang['href_edit_attendance'] = 				"edit attendance";
$lang['href_event_apply'] = 					"apply to attend this event";
$lang['href_group_schedule'] = 					"view group schedule";
$lang['href_network_schedule'] = 				"view their schedule";
$lang['href_view_node'] = 						"latest from the community";
$lang['href_view_network'] = 					"latest from my network";
$lang['href_view_my_groups'] = 					"latest from my groups";
$lang['href_my_schedule'] = 					"my schedule";
$lang['href_marked'] = 							"marked schedule items";
$lang['href_tipped'] = 							"tipped schedule items";
$lang['href_add_event'] = 						"add an event to my schedule";
$lang['href_group_add_event'] = 				"add an event to this group";
$lang['href_add_task'] = 						"add a task to my schedule";
$lang['href_group_add_task'] = 					"add a task to this group";
$lang['href_allocation'] = 						"allocation";


//FORM
$lang['form_label_from_date'] = 				"from";
$lang['form_label_show'] = 						"show next";
$lang['form_label_title'] = 					"title";
$lang['form_label_synopsis'] = 					"synopsis";
$lang['form_sub_find'] = 						"show events";
$lang['form_option_all'] = 						"all";
$lang['form_label_priority'] = 					"priority";
$lang['form_label_tentative'] = 				"include tentative";


//ERRORS
$lang['err_no_schedule_items'] = 				"Sorry, there are no schedule items available.";
$lang['err_no_comments'] = 						"Sorry, there are no comments available.";


//BODY TEXT
$lang['txt_date'] = 							"date";
$lang['txt_applicants'] = 						"These people have applied for this item. Please ensure you inform them via AROUNDMe messaging if you change their status. Note: Once you set a person's status to 'confirmed' you will not be able to change it. Only they can.";
$lang['txt_allocation'] = 						"allocation";
$lang['txt_event_search_intro'] = 				"If you want to search for a specific event you can always use our search engine.";
$lang['txt_task_search_intro'] = 				"If you want to search for a specific task you can always use our search engine.";
$lang['txt_event_summary'] = 					"There are SYS_KEYWORD_TOTAL future events in this community";
$lang['txt_task_summary'] = 					"There are SYS_KEYWORD_TOTAL available tasks in this community";
$lang['txt_hint_date'] = 						"Hint: leave the date empty to show non date related tasks.";
$lang['txt_schedule'] = 						"schedule"; // breadcrumb
$lang['txt_occurence_daily'] = 					"daily at"; // usage = daily at 22:00
$lang['txt_occurence_weekly'] = 				"weekly on "; // usage = weekly on Wed 22:00
$lang['txt_occurence_monthly'] = 				"monthly at"; // usage = monthly on Wed 15th 22:00
$lang['txt_occurence_yearly'] = 				"yearly on "; // usage = yearly on Wed 15th Aug 22:00
$lang['txt_event_apply'] = 						"apply to attend this event.";
$lang['txt_event_apply_update'] = 				"reapply for this schedule item";
$lang['txt_event_full'] = 						"Sorry. this event has all the required participants.";
$lang['txt_event_withdraw_confirmation'] =		"If you no longer wish to participate you can withdraw. Please remember to inform the schedule organiser why.";
$lang['txt_allocation'] = 						"allocation";
$lang['txt_applications'] = 					"applications";
$lang['txt_confirmed'] = 						"confirmed";
$lang['txt_end'] = 								"end";
$lang['txt_location'] = 						"location";
$lang['txt_start'] = 							"start";
$lang['txt_event_allocation_intro'] = 			"You can attend this event. You can withdraw from an event at any time.";
$lang['txt_allocation_full'] = 					"sorry, there are no places left";
$lang['txt_priority'] = 						"priority";
$lang['txt_complete'] = 						"completed";
$lang['txt_p_complete'] = 						"percentage complete";
$lang['txt_no_start'] = 						"no start date";
$lang['txt_no_end'] = 							"no end date";
$lang['txt_all_day_item'] = 					"all day item";
$lang['txt_application'] = 						"attendance application";
$lang['txt_application_rejected'] = 			"Your application to attend this event was rejected by the event author. If you have your default profile set to allow messaging you should have received a message from the organiser explaining their decision. If you are not happy then contact the community administrator.";
$lang['txt_published_to'] = 					"Published to";
$lang['txt_group_type'] = 						"type";
$lang['txt_rec_age'] = 							"age";
$lang['txt_age_all'] = 							"all";
$lang['txt_age_from'] = 						"from";
$lang['txt_age_upto'] = 						"upto";
$lang['txt_hidden'] = 							"hidden";
$lang['txt_statistics'] = 						"statistics";
$lang['txt_tag'] = 								"tags";
$lang['txt_options'] = 							"options";
$lang['txt_view'] = 							"view";
$lang['txt_group_link'] = 						"This schedule is from the group";
$lang['txt_intro_group'] = 						"Listed are the last SYS_KEYWORD_NUMBER (max) schedule items that have been published by the groups that you are a member of.";
$lang['txt_intro_node'] = 						"Listed are the last SYS_KEYWORD_NUMBER (max) schedule items that have been published by a member of this community.";
$lang['txt_intro_network'] = 					"Listed are the last SYS_KEYWORD_NUMBER (max) schedule items that have been published by a person in your network.";
$lang['txt_outro_group'] = 						"The following groups have not published a schedule item within the last SYS_KEYWORD_NUMBER.";
$lang['txt_outro_network'] = 					"The following people in your network have not published a schedule item within the last SYS_KEYWORD_NUMBER.";
$lang['txt_status'] = 							"status";
$lang['txt_intro_marked'] = 					"You have bookmarked the following items for reading. You can manage your bookmarks under 'Me', 'marks &amp; tips'.";
$lang['txt_intro_tipped'] = 					"Your network have recommended (tipped) the following items for reading. You can manage your recommendations to your network under 'Me', 'marks &amp; tips'.";

?>

==> aroundme_0_6_9.tar.tgz: aroundme_0_6_9/aroundme/language/1/barnraiser_01/sch_view.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------


//SECTION
$lang['hdr_schedule'] = 						"my schedule";
$lang['hdr_group_schedule'] = 					"group schedule";
$lang['hdr_my_group_schedule_items'] = 			"latest schedule items from my groups";
$lang['hdr_my_network_schedule_items'] = 		"latest schedule items from my network";
$lang['hdr_options'] =							"schedule options";
$lang['hdr_schedule_item_author'] = 			"author";
$lang['hdr_schedule_item_group_author'] = 		"authoring group";
$lang['hdr_task_allocated'] = 					"allocated tasks";
$lang['hdr_task_initiated'] = 					"initiated tasks";
$lang['hdr_event_attendance'] = 				"event attendance";
$lang['hdr_event_initiated'] = 					"initiated events";
$lang['hdr_events'] = 							"events";
$lang['hdr_tasks'] = 							"tasks";
$lang['hdr_schedule_items'] = 					"schedule items";
$lang['hdr_schedule_item'] = 					"schedule item";
$lang['hdr_allocation'] = 						"allocation";
$lang['hdr_detail'] = 							"details";
$lang['hdr_attendance'] = 						"attendance";


// HREF
$lang['href_event_withdraw_confirmation'] = 	"withdraw from this event";
//$lang['href_edit_attendance'] = 				"edit attendance";
$lang['href_event_apply'] = 					"apply to attend this event";
$lang['href_group_schedule'] = 					"view group schedule";
$lang['href_network_schedule'] = 				"view their schedule";
$lang['href_view_node'] = 						"latest from the community";
$lang['href_view_network'] = 					"latest from my network";
$lang['href_view_my_groups'] = 					"latest from my groups";
$lang['href_my_schedule'] = 					"my schedule";
$lang['href_marked'] = 							"marked schedule items";
$lang['href_tipped'] = 							"tipped schedule items";
$lang['href_add_event'] = 						"add an event to my schedule";
$lang['href_group_add_event'] = 				"add an event to this group";
$lang['href_add_task'] = 						"add a task to my schedule";
$lang['href_group_add_task'] = 					"add a task to this group";
$lang['href_allocation'] = 						"allocation";
$lang['href_edit_allocation'] = 				"edit allocation";


//FORM
$lang['form_label_from_date'] = 				"from";
$lang['form_label_show'] = 						"show next";
$lang['form_label_title'] = 					"title";
$lang['form_label_synopsis'] = 					"synopsis";
$lang['form_sub_find'] = 						"show events";
$lang['form_option_all'] = 						"all";
$lang['form_label_priority'] = 					"priority";
$lang['form_label_tentative'] = 				"include tentative";


//ERRORS
$lang['err_no_schedule_items'] = 				"Sorry, there are no schedule items available.";
$lang['err_no_comments'] = 						"Sorry, there are no comments available.";


//BODY TEXT
$lang['txt_date'] = 							"date";
$lang['txt_applicants'] = 						"These people have applied for this item. Please ensure you inform them via AROUNDMe messaging if you change their status. Note: Once you set a person's status to 'confirmed' you will not be able to change it. Only they can.";
$lang['txt_allocation'] = 						"allocation";
$lang['txt_event_search_intro'] = 				"If you want to search for a specific event you can always use our search engine.";
$lang['txt_task_search_intro'] = 				"If you want to search for a specific task you can always use our search engine.";
$lang['txt_event_summary'] = 					"There are SYS_KEYWORD_TOTAL future events in this community";
$lang['txt_task_summary'] = 					"There are SYS_KEYWORD_TOTAL available tasks in this community";
$lang['txt_hint_date'] = 						"Hint: leave the date empty to show non date related tasks.";
$lang['txt_schedule'] = 						"schedule"; // breadcrumb
$lang['txt_occurence_daily'] = 					"daily at"; // usage = daily at 22:00
$lang['txt_occurence_weekly'] = 				"weekly on "; // usage = weekly on Wed 22:00
$lang['txt_occurence_monthly'] = 				"monthly at"; // usage = monthly on Wed 15th 22:00
$lang['txt_occurence_yearly'] = 				"yearly on "; // usage = yearly on Wed 15th Aug 22:00
$lang['txt_event_apply'] = 						"apply to attend this event.";
$lang['txt_event_apply_update'] = 				"reapply for this schedule item";
$lang['txt_event_full'] = 						"Sorry. this event has all the required participants.";
$lang['txt_event_withdraw_confirmation'] =		"If you no longer wish to participate you can withdraw. Please remember to inform the schedule organiser why.";
$lang['txt_allocation'] = 						"allocation";
$lang['txt_applications'] = 					"applications";
$lang['txt_confirmed'] = 						"confirmed";
$lang['txt_end'] = 								"end";
$lang['txt_location'] = 						"location";
$lang['txt_start'] = 							"start";
$lang['txt_event_allocation_intro'] = 			"You can attend this event. You can withdraw from an event at any time.";
$lang['txt_allocation_full'] = 					"sorry, there are no places left";
$lang['txt_priority'] = 						"priority";
$lang['txt_complete'] = 						"completed";
$lang['txt_p_complete'] = 						"percentage complete";
$lang['txt_no_start'] = 						"no start date";
$lang['txt_no_end'] = 							"no end date";
$lang['txt_all_day_item'] = 					"all day item";
$lang['txt_application'] = 						"attendance application";
$lang['txt_application_rejected'] = 			"Your application to attend this event was rejected by the event author. If you have your default profile set to allow messaging you should have received a message from the organiser explaining their decision. If you are not happy then contact the community administrator.";
$lang['txt_published_to'] = 					"Published to";
$lang['txt_group_type'] = 						"type";
$lang['txt_rec_age'] = 							"age";
$lang['txt_age_all'] = 							"all";
$lang['txt_age_from'] = 						"from";
$lang['txt_age_upto'] = 						"upto";
$lang['txt_hidden'] = 							"hidden";
$lang['txt_statistics'] = 						"statistics";
$lang['txt_tag'] = 								"tags";
$lang['txt_options'] = 							"options";
$lang['txt_view'] = 							"view";
$lang['txt_group_link'] = 						"This schedule is from the group";
$lang['txt_intro_group'] = 						"Listed are the last SYS_KEYWORD_NUMBER (max) schedule items that have been published by the groups that you are a member of.";
$lang['txt_intro_node'] = 						"Listed are the last SYS_KEYWORD_NUMBER (max) schedule items that have been published by a member of this community.";
$lang['txt_intro_network'] = 					"Listed are the last SYS_KEYWORD_NUMBER (max) schedule items that have been published by a person in your network.";
$lang['txt_outro_group'] = 						"The following groups have not published a schedule item within the last SYS_KEYWORD_NUMBER.";
$lang['txt_outro_network'] = 					"The following people in your network have not published a schedule item within the last SYS_KEYWORD_NUMBER.";
$lang['txt_status'] = 							"status";
$lang['txt_intro_marked'] = 					"You have bookmarked the following items for reading. You can manage your bookmarks under 'Me', 'marks &amp; tips'.";
$lang['txt_intro_tipped'] = 					"Your network have recommended (tipped) the following items for reading. You can manage your recommendations to your network under 'Me', 'marks &amp; tips'.";
$lang['txt_ical_export'] = 						"export to iCal";

?>
